#!/usr/bin/perl

use strict;
use warnings;
use Getopt::Long;
use Pod::Usage;
use URI::Escape;
use Digest::MD5 qw(md5_hex);
use File::Copy;

my $name;
my $member;
my $fileCount;

my $man = 0;
my $help = 0;

my $seek1 = "Attachment ID";
my $seek2 = "image";

my @kdeLocalprefix = ("kde4-config", '--localprefix');
chomp(my $kdeHome = `@kdeLocalprefix`) or die "Can't find the kde home";

my $ffmpegthumbsDir = $kdeHome . "share/apps/ffmpegthumbs-mattepaint/";
my $attachmentsToThumbnail = $ffmpegthumbsDir . "cleanOne";

mkdir $ffmpegthumbsDir;

GetOptions('help|?' => \$help, man => \$man) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-verbose => 2) if $man;
pod2usage("$0: No files given. Try with the -help")  if ((@ARGV == 0) && (-t STDIN));

$ARGV[0] =~ s' /' //'g;
my @fileNames = split(' /', $ARGV[0]);

# extract attached poster to the ../ffmpegthumbs-mattepaint/cleanOne
foreach $name (@fileNames) {
   my $i = 0;

   my $fullName = "file://" . $name;
   my $escapedName = uri_escape("$fullName", "^A-Za-z0-9\-\._~/:()&'");
   my $thumbName = md5_hex("$escapedName") . ".png";
  
   my @attachmentList = `"mkvmerge" '-i' "$name"` or die `"kdialog" "--error" "Can't execute the mkvmerge"`;

   foreach my $line (@attachmentList) {
      if ( $line =~/$seek1/ ) {
         $i++;
         if ( $line =~/$seek2/ ) {
            my @extractCall = ( "mkvextract", "attachments", "$name", "$i:$attachmentsToThumbnail");
            system (@extractCall) == 0 or die `"kdialog" "--error" "Can't execute the mkvextract"`;
            last;
         }
      }
   }

#  remove old thumbnails
   unlink("$ENV{ HOME }/.thumbnails/large/$thumbName");
   unlink("$ENV{ HOME }/.thumbnails/normal/$thumbName");

#  refresh/reload the filemanager window
   my @konquerors = `"qdbus" "org.kde.konqueror*"`;
   chomp (@konquerors);
   foreach $member (@konquerors) { system ("qdbus $member /konqueror/MainWindow_1 activateAction reload 2>/dev/null"); }

   my @dolphins = `"qdbus" "org.kde.dolphin*"`;
   chomp (@dolphins);
   foreach $member (@dolphins) { system ("qdbus $member /dolphin/Dolphin_1 activateAction reload 2>/dev/null"); }

#  wait new thumbnail
   open( DUMP , ">/dev/null" );
   until ( -e "$ENV{ HOME }/.thumbnails/large/$thumbName" || -e  "$ENV{ HOME }/.thumbnails/normal/$thumbName" ) { 
      print DUMP "waiting thumbnail \n"; 
   }
   close (DUMP);
}

__END__

=head1 NAME

matroska-image-to-thumbnail - A Perl helper scrip to use the attached mkv file pictures as the KDE video thumbnail

=head1 SYNOPSIS

matroska-image-to-thumbnail [options] [file(s)]

Options:

-help            this help message

-man             a bit more text

=head1 DESCRIPTION

B<matroska-image-to-thumbnail> will write the first attached picture from the mkv file to the ../share/apps/ffmpegthumbs-mattepaint/thumbnails/cleanOne 
and remove the existing thumbnail. Finally the script will reload the Dolphin/Konqueror windows.

=cut
