#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use Pod::Usage;
use URI::Escape;
use Digest::MD5 qw(md5_hex);
use File::Copy;
use File::Basename;

my $man = 0;
my $help = 0;

my @kdeLocalprefix = ("kde4-config", '--localprefix');
chomp(my $kdeHome = `@kdeLocalprefix`) or die "Can't find the kde home";
my $imageTothumb = $kdeHome . "share/apps/ffmpegthumbs-mattepaint/cleanOne";

my $createMissingdir = $kdeHome . "share/apps/ffmpegthumbs-mattepaint";
mkdir $createMissingdir;

my $name;
my $member;

GetOptions('help|?' => \$help, man => \$man) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-verbose => 2) if $man;
pod2usage("$0: No files given. Try with the -help")  if ((@ARGV == 0) && (-t STDIN));

$ARGV[0] =~ s' /' //'g;
my @fileNames = split(' /', $ARGV[0]);

my $dirname  = dirname($fileNames[0]);

# copy wanted picture to the ../ffmpegthumbs-mattepaint/cleanOne
foreach $name (@fileNames) {
   my $fullName = "file://" . $name;
   my $escapedName = uri_escape("$fullName", "^A-Za-z0-9\-\._~/:()&'");
   my $thumbName = md5_hex("$escapedName") . ".png";
  
   my $pickImage = `"kdialog" '--getopenfilename' '$dirname' '*.png *.jpg'`;
   chomp ($pickImage);
   copy ( $pickImage, $imageTothumb);

#  remove old thumbnails
   unlink("$ENV{ HOME }/.thumbnails/large/$thumbName");
   unlink("$ENV{ HOME }/.thumbnails/normal/$thumbName");

#  refresh/reload the filemanager window
   my @konquerors = `"qdbus" "org.kde.konqueror*"`;
   chomp (@konquerors);
   foreach $member (@konquerors) { system ("qdbus $member /konqueror/MainWindow_1 activateAction reload 2>/dev/null"); }

   my @dolphins = `"qdbus" "org.kde.dolphin*"`;
   chomp (@dolphins);
   foreach $member (@dolphins) { system ("qdbus $member /dolphin/Dolphin_1 activateAction reload 2>/dev/null"); }
}

__END__

=head1 NAME

pick-image-to-thumbnail - A Perl helper scrip to use the picked image as the KDE video thumbnail

=head1 SYNOPSIS

pick-image-to-thumbnail.pl [options] [file(s)]

Options:

-help            this help message

-man             a bit more text

=head1 DESCRIPTION

B<pick-image-to-thumbnail> will write the picked picture to the ../share/apps/ffmpegthumbs-mattepaint/cleanOne
and remove the existing thumbnails. Finally the script will reload the Dolphin/Konqueror windows.

=cut 