#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use Pod::Usage;
use URI::Escape;
use Digest::MD5 qw(md5_hex);
use File::Copy;

my $man = 0;
my $help = 0;

my @kdeLocalprefix = ("kde4-config", '--localprefix');
chomp(my $kdeHome = `@kdeLocalprefix`) or die "Can't find the kde home";
my $snapTothumb = $kdeHome . "share/apps/ffmpegthumbs-mattepaint/chosenOne";

my $smplayerIni = "$ENV{ HOME }/.config/smplayer/smplayer.ini";
my $smplayerConfig = $kdeHome . "share/apps/ffmpegthumbs-mattepaint/smplayer";
my $thumbfixerIni = $smplayerConfig . "/smplayer.ini";
my $imageTothumb = $kdeHome . "share/apps/ffmpegthumbs-mattepaint/chosenOne";
my $seek = "screenshot_folder=";
my $replace = "screenshot_folder=$smplayerConfig/smplayer_screenshots \n";
my $smplayerShot = $smplayerConfig . "/smplayer_screenshots" . "/shot0001.png";

my $createMissingdir = $kdeHome . "share/apps/ffmpegthumbs-mattepaint";
mkdir $createMissingdir;
mkdir $createMissingdir . "/smplayer";
mkdir $createMissingdir . "/smplayer" ."/smplayer_screenshots";

my $name;
my $member;
my $row;

GetOptions('help|?' => \$help, man => \$man) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-verbose => 2) if $man;
pod2usage("$0: No files given. Try with the -help")  if ((@ARGV == 0) && (-t STDIN));

$ARGV[0] =~ s' /' //'g;
my @fileNames = split(' /', $ARGV[0]);

if ( !-e $thumbfixerIni ) {
   open(IN, "<$smplayerIni");
   open(OUT, ">$thumbfixerIni");

   while($row=<IN>) {
      if ($row =~/$seek/) {
         $row = $replace;
         print OUT $row;
      } else {
         print OUT $row;
     }
   }
}

# move snapshot to the ../ffmpegthumbs-mattepaint/chosenOne
foreach $name (@fileNames) {
   my $fullName = "file://" . $name;
   my $escapedName = uri_escape("$fullName", "^A-Za-z0-9\-\._~/:()&'");
   my $thumbName = md5_hex("$escapedName") . ".png";
  
   my @smplayerCall = ("smplayer", '-config-path', "$smplayerConfig", "$name");
   system @smplayerCall;
  
   move ( $smplayerShot, $imageTothumb);

#  remove old thumbnails
   unlink("$ENV{ HOME }/.thumbnails/large/$thumbName");
   unlink("$ENV{ HOME }/.thumbnails/normal/$thumbName");

#  refresh/reload the filemanager window
   my @konquerors = `"qdbus" "org.kde.konqueror*"`;
   chomp (@konquerors);
   foreach $member (@konquerors) { system ("qdbus $member /konqueror/MainWindow_1 activateAction reload 2>/dev/null"); }

   my @dolphins = `"qdbus" "org.kde.dolphin*"`;
   chomp (@dolphins);
   foreach $member (@dolphins) { system ("qdbus $member /dolphin/Dolphin_1 activateAction reload 2>/dev/null"); }

}

__END__

=head1 NAME

smplayer-screenshot-to-thumbnail - A Perl helper scrip to use the SMPlayer screenshot as the KDE video thumbnail

=head1 SYNOPSIS

smplayer-screenshot-to-thumbnail.pl [options] [file(s)]

Options:

-help            this help message

-man             a bit more text

=head1 DESCRIPTION

B<smplayer-screenshot-to-thumbnail> will write the SMPlayer screenshot to the ../share/apps/ffmpegthumbs-mattepaint/chosenOne 
and remove the existing thumbnails. Finally the script will reload the Dolphin/Konqueror windows.

=cut 