#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use Pod::Usage;
use URI::Escape;
use Digest::MD5 qw(md5_hex);
use File::Copy;
use File::Basename;

my $man = 0;
my $help = 0;

my @kdeLocalprefix = ("kde4-config", '--localprefix');
chomp(my $kdeHome = `@kdeLocalprefix`) or die "Can't find the kde home";
my $imageTothumb = $kdeHome . "share/apps/ffmpegthumbs-mattepaint/cleanOne";

my $createMissingdir = $kdeHome . "share/apps/ffmpegthumbs-mattepaint";
mkdir $createMissingdir;

my $name;
my $member;
my $poster;

GetOptions('help|?' => \$help, man => \$man) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-verbose => 2) if $man;
pod2usage("$0: No files given. Try with the -help")  if ((@ARGV == 0) && (-t STDIN));

$ARGV[0] =~ s' /' //'g;
my @fileNames = split(' /', $ARGV[0]);

my $dirname  = dirname($fileNames[0]);
my $pickDir = `"kdialog" '--getexistingdirectory' '$dirname'`;
chomp ($pickDir);

opendir(DIR, "$pickDir");
my @posterNames= grep(/(.png|.jpg)$/,readdir(DIR));

foreach $name (@fileNames) {
   my $fullName = "file://" . $name;
   my $escapedName = uri_escape("$fullName", "^A-Za-z0-9\-\._~/:()&'");
   my $thumbName = md5_hex("$escapedName") . ".png";
   my $basename = basename($name);
   my $basenameSubstr = substr $basename, 0, 5;

# copy poster to the ../ffmpegthumbs-mattepaint/cleanOne
   foreach $poster (@posterNames) {
      if  ( $poster =~ m/^$basenameSubstr/i ) {
         my $pickImage = $pickDir . "/" . $poster;
         copy ( $pickImage, $imageTothumb);
         last; 
      }
   }

#  remove old thumbnails
   unlink("$ENV{ HOME }/.thumbnails/large/$thumbName");
   unlink("$ENV{ HOME }/.thumbnails/normal/$thumbName");

#  refresh/reload the filemanager window
   my @konquerors = `"qdbus" "org.kde.konqueror*"`;
   chomp (@konquerors);
   foreach $member (@konquerors) { system ("qdbus $member /konqueror/MainWindow_1 activateAction reload 2>/dev/null"); }

   my @dolphins = `"qdbus" "org.kde.dolphin*"`;
   chomp (@dolphins);
   foreach $member (@dolphins) { system ("qdbus $member /dolphin/Dolphin_1 activateAction reload 2>/dev/null"); }

#  wait new thumbnail
   open( DUMP , ">/dev/null" );
   until ( -e "$ENV{ HOME }/.thumbnails/large/$thumbName" || -e  "$ENV{ HOME }/.thumbnails/normal/$thumbName" ) { 
      print DUMP "waiting thumbnail \n";
      select(undef, undef, undef, 0.25);
   }
   close (DUMP);
}

__END__

=head1 NAME

use-posters-as-thumbnail - A Perl helper scrip to use the picked image as the KDE video thumbnail

=head1 SYNOPSIS

use-posters-as-thumbnail.pl [options] [file(s)]

Options:

-help            this help message

-man             a bit more text

=head1 DESCRIPTION

B<use-posters-as-thumbnail> will write the picture from the picked directory to the ../share/apps/ffmpegthumbs-mattepaint/cleanOne
and remove the existing thumbnails. Finally the script will reload the Dolphin/Konqueror windows. Note that the use-posters-as-thumbnail is only checking five characters from the begin. 

=cut 