#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use Pod::Usage;
use URI::Escape;
use Digest::MD5 qw(md5_hex);

my $man = 0;
my $help = 0;

my $name;
my $member;

GetOptions('help|?' => \$help, man => \$man) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-verbose => 2) if $man;
pod2usage("$0: No files given. Try with the -help")  if ((@ARGV == 0) && (-t STDIN));

$ARGV[0] =~ s' /' //'g;
my @fileNames = split(' /', $ARGV[0]);

foreach $name (@fileNames) {
   my $fullName = "file://" . $name;
   my $escapedName = uri_escape("$fullName", "^A-Za-z0-9\-\._~/:()&'");
   my $thumbName = md5_hex("$escapedName") . ".png";

#  remove old thumbnails
   unlink("$ENV{ HOME }/.thumbnails/large/$thumbName");
   unlink("$ENV{ HOME }/.thumbnails/normal/$thumbName");
}

#  refresh/reload the filemanager window
my @konquerors = `"qdbus" "org.kde.konqueror*"`;
chomp (@konquerors);
foreach $member (@konquerors) { system ("qdbus $member /konqueror/MainWindow_1 activateAction reload 2>/dev/null"); }

my @dolphins = `"qdbus" "org.kde.dolphin*"`;
chomp (@dolphins);
foreach $member (@dolphins) { system ("qdbus $member /dolphin/Dolphin_1 activateAction reload 2>/dev/null"); }


__END__

=head1 NAME

video-thumbnail-remover - A Perl scrip to remove the selected video thumbnails

=head1 SYNOPSIS

video-thumbnail-remover.pl [options] [file(s)]

Options:

-help            this help message

-man             a bit more text

=head1 DESCRIPTION

B<video-thumbnail-remover> will read the given input video file names and remove
the thumbnail image files.

=cut 